@@ -12,17 +12,16 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from tests import mock
-from tests import unittest
-import datetime
-import time
 import base64
+import datetime
 import json
+import time
 
 import botocore.auth
 import botocore.credentials
-from botocore.compat import HTTPHeaders, urlsplit, parse_qs, six
 from botocore.awsrequest import AWSRequest
+from botocore.compat import HTTPHeaders, parse_qs, six, urlsplit
+from tests import mock, unittest
 
 
 class BaseTestWithFixedDate(unittest.TestCase):
